@@ -115,14 +115,62 @@ test_that('guess_knitr_output_format() gets it right', {
 })
 
 
+expect_outputs_unchanged <- function (hx, idx) {
+  info <- paste0("Index i = ", idx)
+  file <- file.path(test_path(), "example-rds", paste0("various-outputs-", idx))
+  expect_known_value(to_screen(hx), file = paste0(file, "-screen.rds"), info = info)
+  expect_known_value(to_md(hx),     file = paste0(file, "-md.rds"),     info = info)
+  expect_known_value(to_html(hx),   file = paste0(file, "-html.rds"),   info = info)
+  expect_known_value(to_latex(hx),  file = paste0(file, "-latex.rds"),  info = info)
+}
+
+
+test_that('various outputs unchanged', {
+  skip_on_R_CMD_check()
+  hx <- hux(
+          int  = 1:3,
+          real = 1:3 + 0.005,
+          char = letters[1:3],
+          date = as.Date(1:3, origin = "1970-01-01"),
+          fact = factor(letters[4:6])
+        )
+  variations <- expand.grid(
+          align             = c('left', 'right', 'centre', '.'),
+          background_color  = c('red', grey(.6), NA),
+          bold              = c(TRUE, FALSE),
+          escape_contents   = c(TRUE, FALSE),
+          font_size         = c(8, 10),
+          italic            = c(TRUE, FALSE),
+          left_border       = c(0, 1, 2),
+          left_border_color = c('red', grey(.6)),
+          left_padding      = c(0, 4),
+          number_format     = c("%3.1g", NA),
+          rotation          = c(0, 90),
+          text_color        = c('red', grey(.6)),
+          valign            = c('top', 'middle', 'bottom'),
+          wrap              = c(TRUE, FALSE),
+          stringsAsFactors  = FALSE,
+          KEEP.OUT.ATTRS   = FALSE
+        )
+  RNGversion("3.3.0")
+  set.seed(271075L) # expect_unchanged is useless if we always pick new variations
+  for (i in sample(nrow(variations), 300)) {
+    props <- as.list(variations[i,])
+    props$ht <- hx
+    hx_set <- do.call("set_cell_properties", props)
+    expect_outputs_unchanged(hx_set, i)
+  }
+})
+
 test_that('set_print_method() works', {
   ht <- hux(a = 1:2, b = 1:2)
-  options(huxtable.print = print_html)
+  oo <- options(huxtable.print = print_html)
   expect_match(capture.output(print(ht)), '<table', fixed = TRUE, all = FALSE)
   options(huxtable.print = print_latex)
   expect_match(capture.output(print(ht)), 'tabular', fixed = TRUE, all = FALSE)
   options(huxtable.print = 'print_html')
   expect_match(capture.output(print(ht)), '<table', fixed = TRUE, all = FALSE)
+  options(oo)
 })
 
 
@@ -131,10 +179,6 @@ test_that('Quick output functions work', {
   m <- matrix(1:4, 2, 2)
   dfr <- data.frame(a = 1:5, b = 1:5)
 
-  tf <- tempfile(fileext = '.pdf')
-  expect_silent(quick_pdf(m, dfr, ht, file = tf))
-  expect_true(file.exists(tf))
-
   tf <- tempfile(fileext = '.htm')
   expect_silent(quick_html(m, dfr, ht, file = tf))
   expect_true(file.exists(tf))
@@ -148,9 +192,19 @@ test_that('Quick output functions work', {
   expect_true(file.exists(tf))
 })
 
+test_that('quick_pdf works', {
+  skip_on_appveyor()
+  ht <- hux(a = 1:2, b = 1:2)
+  m <- matrix(1:4, 2, 2)
+  dfr <- data.frame(a = 1:5, b = 1:5)
+  tf <- tempfile(fileext = '.pdf')
+  expect_silent(quick_pdf(m, dfr, ht, file = tf))
+  expect_true(file.exists(tf))
+})
+
 
 test_that('Quick output functions stop if called non-interactively with no `file` argument', {
   ht <- hux(a = 1:2, b = 1:2)
-  expect_error(quick_pdf(ht))
-  expect_false(file.exists('huxtable-output.pdf'))
+  expect_error(quick_html(ht))
+  expect_false(file.exists('huxtable-output.html'))
 })
